@@ -11,6 +11,7 @@ except ModuleNotFoundError:
     # Fallback for Python 3.7
     from importlib_metadata import version
 
+from itertools import filterfalse
 from pathlib import Path
 from typing import Dict, List, Optional
 
@@ -37,7 +38,7 @@ class Hapless(object):
             self._hapless_dir.mkdir(parents=True, exist_ok=True)
 
     @staticmethod
-    def stats(haps: List[Hap]):
+    def stats(haps: List[Hap], verbose: bool = False):
         if not haps:
             console.print(
                 f"{config.ICON_INFO} No haps are currently running",
@@ -47,28 +48,43 @@ class Hapless(object):
 
         package_version = version(__package__)
         table = Table(
-            title=f"{config.ICON_HAP} {__package__}, {package_version}",
             show_header=True,
             header_style=f"{config.COLOR_MAIN} bold",
             box=box.HEAVY_EDGE,
+            caption_style="dim",
+            caption_justify="right",
         )
         table.add_column("#", style="dim", width=2)
         table.add_column("Name")
         table.add_column("PID")
+        if verbose:
+            table.add_column("Command")
         table.add_column("Status")
         table.add_column("RC")
         table.add_column("Runtime", justify="right")
 
+        active_haps = 0
         for hap in haps:
-            table.add_row(
+            active_haps += 1 if hap.active else 0
+            pid_text = f"{hap.pid}" if hap.active else Text(f"{hap.pid}", style="dim")
+            command_text = Text(
+                hap.cmd, overflow="ellipsis", style=f"{config.COLOR_ACCENT}"
+            )
+            command_text.truncate(config.TRUNCATE_LENGTH)
+            row = [
                 f"{hap.hid}",
                 hap.name,
-                f"{hap.pid}",
+                pid_text,
+                command_text if verbose else None,
                 hap.status,
                 f"{hap.rc}" if hap.rc is not None else "",
                 hap.runtime,
-            )
+            ]
+            table.add_row(*filterfalse(lambda x: x is None, row))
 
+        if verbose:
+            table.title = f"{config.ICON_HAP} {__package__}, {package_version}"
+            table.caption = f"{active_haps} active / {len(haps)} total"
         console.print(table)
 
     @staticmethod
@@ -225,8 +241,8 @@ class Hapless(object):
             )
             sys.exit(1)
 
-    def run(self, cmd: str, check: bool = False):
-        hap = self.create_hap(cmd=cmd)
+    def run(self, cmd: str, name: Optional[str] = None, check: bool = False):
+        hap = self.create_hap(cmd=cmd, name=name)
         pid = os.fork()
         if pid == 0:
             coro = self.run_hap(hap)
@@ -238,6 +254,10 @@ class Hapless(object):
 
     def logs(self, hap: Hap, follow: bool = False):
         if follow:
+            console.print(
+                f"{config.ICON_INFO} Streaming {hap.stdout_path} file...",
+                style=f"{config.COLOR_MAIN} bold",
+            )
             return subprocess.run(["tail", "-f", hap.stdout_path])
         else:
             return subprocess.run(["cat", hap.stdout_path])
